@@ -5,11 +5,12 @@ use warnings;
 use 5.010_001;
 use Carp qw(croak);
 
-use version; our $VERSION = 'v0.3.1';
+use version; our $VERSION = 'v0.3.2';
 
 sub instance     { croak 'Must implement in child class!'; }
 sub gets         { croak 'Must implement in child class!'; }
 sub get_by_id    { croak 'Must implement in child class!'; }
+sub create       { croak 'Must implement in child class!'; }
 sub update_by_id { croak 'Must implement in child class!'; }
 
 1;
@@ -30,6 +31,7 @@ B<App::Koyomi::DataSource::Job> - Abstract datasource class for job entity
     sub instance { ... }
     sub gets { ... }
     sub get_by_id { ... }
+    sub create { ... }
     sub update_by_id { ... }
 
 =head1 DESCRIPTION
@@ -53,6 +55,10 @@ Fetch all job data as array.
 
 Fetch one job data including job_times data.
 
+=item B<create>
+
+Create one job data including job_times data.
+
 =item B<update_by_id>
 
 Update one job data including job_times data.
